@@ -2,7 +2,7 @@
 /* xorriso - libisoburn higher level API which creates, loads, manipulates
              and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2017 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2021 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -73,8 +73,8 @@ struct XorrisO;
     @since 0.5.8
 */
 #define Xorriso_header_version_majoR  1
-#define Xorriso_header_version_minoR  4
-#define Xorriso_header_version_micrO  8
+#define Xorriso_header_version_minoR  5
+#define Xorriso_header_version_micrO  4
 
 
 /** If needed: Something like ".pl01" to indicate a bug fix. Normally empty.
@@ -207,8 +207,8 @@ int Xorriso_startup_libraries(struct XorrisO *xorriso, int flag);
          functions from the Command API.
 
          Wenn all desired activities are done, you may check whether there are
-         uncommited changes pending, compute an exit value, destroy the XorrisO
-         object, and exit your program.
+         uncommitted changes pending, compute an exit value, destroy the
+         XorrisO object, and exit your program.
 */
 
 
@@ -820,6 +820,9 @@ int Xorriso_sieve_dispose(struct XorrisO *xorriso, int flag);
                      (Note: prefix is "Creation Time: ")
     "DVD obs 64 kB:" up to 1 result from -list_extras
                      argv[0]= "yes" or "no"
+    "Drive access: " up to 2 result from -dev, -indev, -toc
+                     argv[0]= "exclusive", "shared"
+                     argv[1]= "readonly","restricted"
     "Drive current:" up to 2 results from -dev, -indev, -toc, others
                      argv[0]= command ("-dev", "-outdev", "-indev")
                      argv[1]= drive address
@@ -1502,6 +1505,10 @@ int Xorriso_option_disk_pattern(struct XorrisO *xorriso, char *mode, int flag);
 int Xorriso_option_displacement(struct XorrisO *xorriso, char *value,
                                 int flag);
 
+/* Command -drive_access "exclusive"|"shared":"readonly"|"unrestricted" */
+/* @since 1.5.2 */
+int Xorriso_option_drive_access(struct XorrisO *xorriso, char *mode, int flag);
+
 /* Command -drive_class */
 /* @since 0.3.2 */
 int Xorriso_option_drive_class(struct XorrisO *xorriso,
@@ -1561,6 +1568,11 @@ int Xorriso_option_external_filter(struct XorrisO *xorriso,
 int Xorriso_option_extract(struct XorrisO *xorriso, char *disk_path,
                        char *iso_path, int flag);
 
+/* Command -extract_boot_images */
+/* @sice 1.5.4 */
+int Xorriso_option_extract_boot_images(struct XorrisO *xorriso,
+                                       char *disk_dir_path, int flag);
+
 /* Command -extract_cut */
 /* @since 0.2.6 */
 int Xorriso_option_extract_cut(struct XorrisO *xorriso, char *iso_rr_path,
@@ -1593,10 +1605,13 @@ int Xorriso_option_follow(struct XorrisO *xorriso, char *mode, int flag);
 /* Command -for_backup is a shortcut for
      Xorriso_option_hardlinks(xorriso, "on", 0);
      Xorriso_option_acl(xorriso, "on", 0);
-     Xorriso_option_xattr(xorriso, "on", 0);
+     Xorriso_option_xattr(xorriso, "any", 0);
      Xorriso_option_md5(xorriso, "on", 0);
 */
 /* @since 0.4.0 */
+/* xattr "any"
+   @since 1.5.0
+*/
 
 /* Command -fs */
 /* @since 0.1.0 */
@@ -1642,6 +1657,10 @@ int Xorriso_option_hide(struct XorrisO *xorriso, char *hide_state,
 /* @since 0.1.0 */
 int Xorriso_option_history(struct XorrisO *xorriso, char *line, int flag);
 
+/* Command -iso_nowtime "dynamic"|timespec */
+/* @since 1.5.2 */
+int Xorriso_option_iso_nowtime(struct XorrisO *xorriso, char *text, int flag);
+
 /* Command -iso_rr_pattern "on"|"ls"|"off" */
 /* @since 0.1.0 */
 int Xorriso_option_iso_rr_pattern(struct XorrisO *xorriso, char *mode,
@@ -1656,6 +1675,9 @@ int Xorriso_option_jigdo(struct XorrisO *xorriso, char *aspect, char *arg,
 /* @since 0.1.0 */
 int Xorriso_option_joliet(struct XorrisO *xorriso, char *mode, int flag);
 
+/* Command -joliet_map "unmapped" | "stripped" */
+int Xorriso_option_joliet_map(struct XorrisO *xorriso, char *mode, int flag);
+
 /* Command -launch_frontend */
 /* @since 1.2.6 */
 int Xorriso_option_launch_frontend(struct XorrisO *xorriso,
@@ -2082,7 +2104,7 @@ int Xorriso_option_status_history_max(struct XorrisO *xorriso, int num1,
 
 /* Command -stdio_sync "on"|"off"|"end"|size */
 /* @since 0.4.6 */
-int Xorriso_option_stdio_sync(struct XorrisO *xorriso, char *rythm, int flag);
+int Xorriso_option_stdio_sync(struct XorrisO *xorriso, char *rhythm, int flag);
 
 /* Command -stream_recording */
 /* @since 0.1.8 */
@@ -2112,6 +2134,12 @@ int Xorriso_option_toc(struct XorrisO *xorriso, int flag);
 /* @since 1.2.6 */
 int Xorriso_option_toc_of(struct XorrisO *xorriso, char *which, int flag);
 
+/* Command -truncate_overwritable */
+/* @since 1.5.4 */
+int Xorriso_option_truncate_overwritable(struct XorrisO *xorriso,
+                                         char *adr_mode, char *adr_value,
+                                         char *adjust, int flag);
+
 /* Command -uid */
 /* @since 0.1.0 */
 int Xorriso_option_uid(struct XorrisO *xorriso, char *uid, int flag);
